summaryrefslogtreecommitdiffstats
path: root/kparts
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-01-07 03:45:53 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-01-07 03:45:53 +0000
commit10308be19ef7fa44699562cc75946e7ea1fdf6b9 (patch)
tree4bc444c00a79e88105f2cfce5b6209994c413ca0 /kparts
parent307136d8eef0ba133b78ceee8e901138d4c996a1 (diff)
downloadtdelibs-10308be19ef7fa44699562cc75946e7ea1fdf6b9.tar.gz
tdelibs-10308be19ef7fa44699562cc75946e7ea1fdf6b9.zip
Revert automated changes
Sorry guys, they are just not ready for prime time Work will continue as always git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdelibs@1212479 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kparts')
-rw-r--r--kparts/COMMENTS8
-rw-r--r--kparts/browserextension.cpp34
-rw-r--r--kparts/browserextension.h18
-rw-r--r--kparts/browserinterface.cpp2
-rw-r--r--kparts/browserinterface.h2
-rw-r--r--kparts/browserrun.cpp20
-rw-r--r--kparts/browserrun.h2
-rw-r--r--kparts/componentfactory.h36
-rw-r--r--kparts/factory.cpp4
-rw-r--r--kparts/factory.h8
-rw-r--r--kparts/genericfactory.h10
-rw-r--r--kparts/historyprovider.cpp6
-rw-r--r--kparts/historyprovider.h4
-rw-r--r--kparts/mainwindow.h4
-rw-r--r--kparts/part.cpp14
-rw-r--r--kparts/part.h4
-rw-r--r--kparts/partmanager.cpp36
-rw-r--r--kparts/partmanager.h8
-rw-r--r--kparts/plugin.cpp10
-rw-r--r--kparts/plugin.h2
-rw-r--r--kparts/statusbarextension.cpp2
-rw-r--r--kparts/statusbarextension.h2
-rw-r--r--kparts/tests/example.cpp2
-rw-r--r--kparts/tests/ghostview.cpp4
-rw-r--r--kparts/tests/normalktm.cpp2
-rw-r--r--kparts/tests/notepad.cpp6
-rw-r--r--kparts/tests/notepad.desktop2
-rw-r--r--kparts/tests/notepadpart.rc4
-rw-r--r--kparts/tests/parts.cpp8
-rw-r--r--kparts/tests/parts.h4
-rw-r--r--kparts/tests/plugin_foobar.rc4
-rw-r--r--kparts/tests/plugin_spellcheck.rc4
32 files changed, 138 insertions, 138 deletions
diff --git a/kparts/COMMENTS b/kparts/COMMENTS
index 9c6142b23..e3e4d8589 100644
--- a/kparts/COMMENTS
+++ b/kparts/COMMENTS
@@ -11,7 +11,7 @@ the BarPosition of the toolbars is solved. Nice :-)
(David) Not sure we want to save whether the statusbar is shown/hidden.
-(Simon) Another thought: Perhaps we should store the tqgeometry information of
+(Simon) Another thought: Perhaps we should store the geometry information of
the containers of the KPartHost in the KPart itself?
(something like KPart-Session Management ;-)
(David) Sounds strange (the child taking care of its host's containers...)
@@ -44,7 +44,7 @@ I think what it wants is "really" activated, no ?
gets activated", in this simple model (no Document/View). The Part gets activated when you can see
its items in the menus/toolbars, there is no "in between" IMO ?
2 - Remind me what konq does with the *bars when a part gets activated ?
-I couldn't tqfind anything with a quick grep in the sources...
+I couldn't find anything with a quick grep in the sources...
I'm still looking for an example when it's useful :)
(Simon) I think that's the whole idea of making KPartManager independent from
@@ -344,7 +344,7 @@ changes.
--------------------------
-David wondering about tqStatus Bar
+David wondering about Status Bar
--------------------------------
Should the statusbar be a *bar like toolbar/menubar, handled by the XML GUI building
(soon "KPartsMainWindow"), and shown/hidden depending on the
@@ -576,7 +576,7 @@ issue compared to what's above though.
delegation.
It works like this:
We have KReadOnlyPart (short KROP) and KonqyViewerExtension (short KVE). KVE is just
- a child of KROP that you can query with the TQObject::child method.
+ a child of KROP that you can query with the QObject::child method.
Views which are konquy aware feature their own implementation of KVE and konquy is
happy :-)
If a KROP does not feature a KVE then Konqui installs a default KVE that just ignores
diff --git a/kparts/browserextension.cpp b/kparts/browserextension.cpp
index aa34f13de..060d9220e 100644
--- a/kparts/browserextension.cpp
+++ b/kparts/browserextension.cpp
@@ -276,14 +276,14 @@ WindowArgs &WindowArgs::operator=( const WindowArgs &args )
return *this;
}
-WindowArgs::WindowArgs( const TQRect &_tqgeometry, bool _fullscreen, bool _menuBarVisible,
+WindowArgs::WindowArgs( const TQRect &_geometry, bool _fullscreen, bool _menuBarVisible,
bool _toolBarsVisible, bool _statusBarVisible, bool _resizable )
{
d = 0;
- x = _tqgeometry.x();
- y = _tqgeometry.y();
- width = _tqgeometry.width();
- height = _tqgeometry.height();
+ x = _geometry.x();
+ y = _geometry.y();
+ width = _geometry.width();
+ height = _geometry.height();
fullscreen = _fullscreen;
menuBarVisible = _menuBarVisible;
toolBarsVisible = _toolBarsVisible;
@@ -342,7 +342,7 @@ public:
};
TQValueList<DelayedRequest> m_requests;
bool m_urlDropHandlingEnabled;
- KBitArray m_actiontqStatus;
+ KBitArray m_actionStatus;
TQMap<int, TQString> m_actionText;
BrowserInterface *m_browserInterface;
};
@@ -370,11 +370,11 @@ BrowserExtension::BrowserExtension( KParts::ReadOnlyPart *parent,
// they're supported or not
ActionSlotMap::ConstIterator it = s_actionSlotMap->begin();
ActionSlotMap::ConstIterator itEnd = s_actionSlotMap->end();
- TQStrList slotNames = tqmetaObject()->slotNames();
+ TQStrList slotNames = metaObject()->slotNames();
for ( int i=0 ; it != itEnd ; ++it, ++i )
{
// Does the extension have a slot with the name of this action ?
- d->m_actiontqStatus.setBit( i, slotNames.tqcontains( it.key()+"()" ) );
+ d->m_actionStatus.setBit( i, slotNames.contains( it.key()+"()" ) );
}
connect( m_part, TQT_SIGNAL( completed() ),
@@ -415,13 +415,13 @@ int BrowserExtension::yOffset()
void BrowserExtension::saveState( TQDataStream &stream )
{
- stream << m_part->url() << (TQ_INT32)xOffset() << (TQ_INT32)yOffset();
+ stream << m_part->url() << (Q_INT32)xOffset() << (Q_INT32)yOffset();
}
void BrowserExtension::restoreState( TQDataStream &stream )
{
KURL u;
- TQ_INT32 xOfs, yOfs;
+ Q_INT32 xOfs, yOfs;
stream >> u >> xOfs >> yOfs;
URLArgs args( urlArgs() );
@@ -483,7 +483,7 @@ void BrowserExtension::pasteRequest()
{
if ( KMessageBox::questionYesNo( m_part->widget(),
i18n( "<qt>Do you want to search the Internet for <b>%1</b>?" ).arg( TQStyleSheet::escape(url) ),
- i18n( "Internet Search" ), KGuiItem( i18n( "&Search" ), "tqfind"),
+ i18n( "Internet Search" ), KGuiItem( i18n( "&Search" ), "find"),
KStdGuiItem::cancel(), "MiddleClickSearch" ) == KMessageBox::Yes)
slotOpenURLRequest( filterData.uri(), KParts::URLArgs() );
}
@@ -521,10 +521,10 @@ BrowserInterface *BrowserExtension::browserInterface() const
void BrowserExtension::slotEnableAction( const char * name, bool enabled )
{
//kdDebug() << "BrowserExtension::slotEnableAction " << name << " " << enabled << endl;
- ActionNumberMap::ConstIterator it = s_actionNumberMap->tqfind( name );
+ ActionNumberMap::ConstIterator it = s_actionNumberMap->find( name );
if ( it != s_actionNumberMap->end() )
{
- d->m_actiontqStatus.setBit( it.data(), enabled );
+ d->m_actionStatus.setBit( it.data(), enabled );
//kdDebug() << "BrowserExtension::slotEnableAction setting bit " << it.data() << " to " << enabled << endl;
}
else
@@ -534,13 +534,13 @@ void BrowserExtension::slotEnableAction( const char * name, bool enabled )
bool BrowserExtension::isActionEnabled( const char * name ) const
{
int actionNumber = (*s_actionNumberMap)[ name ];
- return d->m_actiontqStatus[ actionNumber ];
+ return d->m_actionStatus[ actionNumber ];
}
void BrowserExtension::slotSetActionText( const char * name, const TQString& text )
{
kdDebug() << "BrowserExtension::slotSetActionText " << name << " " << text << endl;
- ActionNumberMap::ConstIterator it = s_actionNumberMap->tqfind( name );
+ ActionNumberMap::ConstIterator it = s_actionNumberMap->find( name );
if ( it != s_actionNumberMap->end() )
{
d->m_actionText[ it.data() ] = text;
@@ -552,7 +552,7 @@ void BrowserExtension::slotSetActionText( const char * name, const TQString& tex
TQString BrowserExtension::actionText( const char * name ) const
{
int actionNumber = (*s_actionNumberMap)[ name ];
- TQMap<int, TQString>::ConstIterator it = d->m_actionText.tqfind( actionNumber );
+ TQMap<int, TQString>::ConstIterator it = d->m_actionText.find( actionNumber );
if ( it != d->m_actionText.end() )
return *it;
return TQString::null;
@@ -684,7 +684,7 @@ void BrowserExtension::virtual_hook( int, void* )
{ /*BASE::virtual_hook( id, data );*/ }
BrowserHostExtension *
-BrowserHostExtension::tqfindFrameParent(KParts::ReadOnlyPart *callingPart, const TQString &frame)
+BrowserHostExtension::findFrameParent(KParts::ReadOnlyPart *callingPart, const TQString &frame)
{
FindFrameParentParams param;
param.parent = 0;
diff --git a/kparts/browserinterface.cpp b/kparts/browserinterface.cpp
index b8de62539..fc9909a9f 100644
--- a/kparts/browserinterface.cpp
+++ b/kparts/browserinterface.cpp
@@ -19,7 +19,7 @@ BrowserInterface::~BrowserInterface()
void BrowserInterface::callMethod( const char *name, const TQVariant &argument )
{
- int slot = tqmetaObject()->tqfindSlot( name );
+ int slot = metaObject()->findSlot( name );
if ( slot == -1 )
return;
diff --git a/kparts/browserinterface.h b/kparts/browserinterface.h
index 37e6cef41..8d3f0ad98 100644
--- a/kparts/browserinterface.h
+++ b/kparts/browserinterface.h
@@ -35,7 +35,7 @@ namespace KParts
* </code>
*
*/
-class KPARTS_EXPORT BrowserInterface : public TQObject
+class KPARTS_EXPORT BrowserInterface : public QObject
{
Q_OBJECT
public:
diff --git a/kparts/browserrun.h b/kparts/browserrun.h
index 0a0ec1be4..79a7386c6 100644
--- a/kparts/browserrun.h
+++ b/kparts/browserrun.h
@@ -98,7 +98,7 @@ namespace KParts {
*/
TQString contentDisposition() const;
- bool serverSuggestsSave() const { return contentDisposition() == TQString::tqfromLatin1("attachment"); }
+ bool serverSuggestsSave() const { return contentDisposition() == TQString::fromLatin1("attachment"); }
enum AskSaveResult { Save, Open, Cancel };
/**
diff --git a/kparts/factory.cpp b/kparts/factory.cpp
index b26cccf22..9be2f4f92 100644
--- a/kparts/factory.cpp
+++ b/kparts/factory.cpp
@@ -39,9 +39,9 @@ Factory::~Factory()
{
}
-Part *Factory::createPart( TQWidget *tqparentWidget, const char *widgetName, TQObject *parent, const char *name, const char *classname, const TQStringList &args )
+Part *Factory::createPart( TQWidget *parentWidget, const char *widgetName, TQObject *parent, const char *name, const char *classname, const TQStringList &args )
{
- Part* part = createPartObject( tqparentWidget, widgetName, parent, name, classname, args );
+ Part* part = createPartObject( parentWidget, widgetName, parent, name, classname, args );
if ( part )
emit objectCreated( part );
return part;
diff --git a/kparts/genericfactory.h b/kparts/genericfactory.h
index 99ce7c3be..950214ee5 100644
--- a/kparts/genericfactory.h
+++ b/kparts/genericfactory.h
@@ -66,7 +66,7 @@ namespace KParts
*
* The template argument has to inherit from KParts::Part and has to implement two methods:
* 1) There needs to be a public constructor with the following signature:
- * MyPart( TQWidget *tqparentWidget, const char *widgetName, TQObject *parent, const char *name, const TQStringList& args )
+ * MyPart( TQWidget *parentWidget, const char *widgetName, TQObject *parent, const char *name, const TQStringList& args )
*
* 2) It needs to provide one static method to create a KAboutData object per
* request, holding information about the component's name, its authors, license, etc.
@@ -97,12 +97,12 @@ namespace KParts
public:
GenericFactory() { }
- virtual KParts::Part *createPartObject( TQWidget *tqparentWidget, const char *widgetName,
+ virtual KParts::Part *createPartObject( TQWidget *parentWidget, const char *widgetName,
TQObject *parent, const char *name,
const char *className,
const TQStringList &args )
{
- T *part = KDEPrivate::ConcreteFactory<T>::create( tqparentWidget,
+ T *part = KDEPrivate::ConcreteFactory<T>::create( parentWidget,
widgetName,
parent,
name,
@@ -125,12 +125,12 @@ namespace KParts
public:
GenericFactory() { }
- virtual KParts::Part *createPartObject( TQWidget *tqparentWidget, const char *widgetName,
+ virtual KParts::Part *createPartObject( TQWidget *parentWidget, const char *widgetName,
TQObject *parent, const char *name,
const char *className,
const TQStringList &args )
{
- TQObject *object = KDEPrivate::MultiFactory< KTypeList<T1, T2> >::create( tqparentWidget,
+ TQObject *object = KDEPrivate::MultiFactory< KTypeList<T1, T2> >::create( parentWidget,
widgetName,
parent, name,
className,
diff --git a/kparts/historyprovider.cpp b/kparts/historyprovider.cpp
index a62c48a8e..416a109f6 100644
--- a/kparts/historyprovider.cpp
+++ b/kparts/historyprovider.cpp
@@ -61,15 +61,15 @@ HistoryProvider::~HistoryProvider()
s_self = 0;
}
-bool HistoryProvider::tqcontains( const TQString& item ) const
+bool HistoryProvider::contains( const TQString& item ) const
{
- return (bool) d->dict.tqfind( item );
+ return (bool) d->dict.find( item );
}
void HistoryProvider::insert( const TQString& item )
{
// no need to allocate memory, we only want to have fast lookup, no mapping
- d->dict.tqreplace( item, (void*) 1 );
+ d->dict.replace( item, (void*) 1 );
emit inserted( item );
}
diff --git a/kparts/historyprovider.h b/kparts/historyprovider.h
index 3040a95bf..40bf36aa7 100644
--- a/kparts/historyprovider.h
+++ b/kparts/historyprovider.h
@@ -38,7 +38,7 @@ namespace KParts {
*
* @author Carsten Pfeiffer <pfeiffer@kde.org>
*/
-class KPARTS_EXPORT HistoryProvider : public TQObject
+class KPARTS_EXPORT HistoryProvider : public QObject
{
Q_OBJECT
@@ -58,7 +58,7 @@ public:
/**
* @returns true if @p item is present in the history.
*/
- virtual bool tqcontains( const TQString& item ) const;
+ virtual bool contains( const TQString& item ) const;
/**
* Inserts @p item into the history.
diff --git a/kparts/mainwindow.h b/kparts/mainwindow.h
index 80ae87d0f..1dbc43975 100644
--- a/kparts/mainwindow.h
+++ b/kparts/mainwindow.h
@@ -88,10 +88,10 @@ protected slots:
virtual void slotSetStatusBarText( const TQString & );
/**
- * Rebuilds the GUI after KEditToolbar changed the toolbar tqlayout.
+ * Rebuilds the GUI after KEditToolbar changed the toolbar layout.
* @see configureToolbars()
* KDE4: make this virtual. (For now we rely on the fact that it's called
- * as a slot, so the metaobject tqfinds it here).
+ * as a slot, so the metaobject finds it here).
*/
void saveNewToolbarConfig();
diff --git a/kparts/part.cpp b/kparts/part.cpp
index d8549706e..fcd426abf 100644
--- a/kparts/part.cpp
+++ b/kparts/part.cpp
@@ -114,7 +114,7 @@ void PartBase::setInstance( KInstance *inst, bool bLoadPlugins )
// install 'instancename'data resource type
KGlobal::dirs()->addResourceType( inst->instanceName() + "data",
KStandardDirs::kde_default( "data" )
- + TQString::tqfromLatin1( inst->instanceName() ) + '/' );
+ + TQString::fromLatin1( inst->instanceName() ) + '/' );
if ( bLoadPlugins )
loadPlugins( m_obj, this, instance() );
}
@@ -162,10 +162,10 @@ Part::~Part()
delete d;
}
-void Part::embed( TQWidget * tqparentWidget )
+void Part::embed( TQWidget * parentWidget )
{
if ( widget() )
- widget()->reparent( tqparentWidget, 0, TQPoint( 0, 0 ), true );
+ widget()->reparent( parentWidget, 0, TQPoint( 0, 0 ), true );
}
TQWidget *Part::widget()
@@ -365,7 +365,7 @@ bool ReadOnlyPart::openURL( const KURL &url )
KURL destURL;
destURL.setPath( m_file );
d->m_job = KIO::file_copy( m_url, destURL, 0600, true, false, d->m_showProgressInfo );
- d->m_job->setWindow( widget() ? widget()->tqtopLevelWidget() : 0 );
+ d->m_job->setWindow( widget() ? widget()->topLevelWidget() : 0 );
emit started( d->m_job );
connect( d->m_job, TQT_SIGNAL( result( KIO::Job * ) ), this, TQT_SLOT( slotJobFinished ( KIO::Job * ) ) );
return true;
@@ -638,7 +638,7 @@ bool ReadWritePart::saveToURL()
return false;
}
d->m_uploadJob = KIO::file_move( uploadUrl, m_url, -1, true /*overwrite*/ );
- d->m_uploadJob->setWindow( widget() ? widget()->tqtopLevelWidget() : 0 );
+ d->m_uploadJob->setWindow( widget() ? widget()->topLevelWidget() : 0 );
connect( d->m_uploadJob, TQT_SIGNAL( result( KIO::Job * ) ), this, TQT_SLOT( slotUploadFinished (KIO::Job *) ) );
return true;
}
@@ -674,7 +674,7 @@ void ReadWritePart::slotUploadFinished( KIO::Job * )
d->m_originalFilePath = TQString::null;
if (d->m_waitForSave)
{
- tqApp->exit_loop();
+ qApp->exit_loop();
}
}
@@ -692,7 +692,7 @@ bool ReadWritePart::waitSaveComplete()
TQWidget dummy(0,0,WType_Dialog | WShowModal);
dummy.setFocusPolicy( TQWidget::NoFocus );
qt_enter_modal(&dummy);
- tqApp->enter_loop();
+ qApp->enter_loop();
qt_leave_modal(&dummy);
d->m_waitForSave = false;
diff --git a/kparts/part.h b/kparts/part.h
index 794db0b55..0c4023f6c 100644
--- a/kparts/part.h
+++ b/kparts/part.h
@@ -172,7 +172,7 @@ private:
* <b>About the GUI elements:</b>\n
*
* Those elements trigger actions, defined by the part (action()).
- * The tqlayout of the actions in the GUI is defined by an XML file (setXMLFile()).
+ * The layout of the actions in the GUI is defined by an XML file (setXMLFile()).
*
* See also ReadOnlyPart and ReadWritePart, which define the
* framework for a "viewer" part and for an "editor"-like part.
@@ -208,7 +208,7 @@ public:
* This method is not recommended since creating the widget with the correct
* parent is simpler anyway.
*/
- virtual void embed( TQWidget * tqparentWidget );
+ virtual void embed( TQWidget * parentWidget );
/**
* @return The widget defined by this part, set by setWidget().
diff --git a/kparts/partmanager.cpp b/kparts/partmanager.cpp
index 2059af928..0ff139532 100644
--- a/kparts/partmanager.cpp
+++ b/kparts/partmanager.cpp
@@ -97,7 +97,7 @@ PartManager::PartManager( TQWidget * parent, const char * name )
{
d = new PartManagerPrivate;
- tqApp->installEventFilter( this );
+ qApp->installEventFilter( this );
d->m_policy = Direct;
@@ -109,7 +109,7 @@ PartManager::PartManager( TQWidget *topLevel, TQObject *parent, const char *name
{
d = new PartManagerPrivate;
- tqApp->installEventFilter( this );
+ qApp->installEventFilter( this );
d->m_policy = Direct;
@@ -129,7 +129,7 @@ PartManager::~PartManager()
}
// core dumps ... setActivePart( 0L );
- tqApp->removeEventFilter( this );
+ qApp->removeEventFilter( this );
delete d;
}
@@ -206,7 +206,7 @@ bool PartManager::eventFilter( TQObject *obj, TQEvent *ev )
{
TQPoint pos;
- if ( !d->m_managedTopLevelWidgets.tqcontainsRef( w->tqtopLevelWidget() ) )
+ if ( !d->m_managedTopLevelWidgets.containsRef( w->topLevelWidget() ) )
return false;
if ( d->m_bIgnoreScrollBars && w->inherits( "QScrollBar" ) )
@@ -215,9 +215,9 @@ bool PartManager::eventFilter( TQObject *obj, TQEvent *ev )
if ( mev ) // mouse press or mouse double-click event
{
pos = mev->globalPos();
- part = tqfindPartFromWidget( w, pos );
+ part = findPartFromWidget( w, pos );
} else
- part = tqfindPartFromWidget( w );
+ part = findPartFromWidget( w );
#ifdef DEBUG_PARTMANAGER
TQCString evType = ( ev->type() == TQEvent::MouseButtonPress ) ? "MouseButtonPress"
@@ -288,7 +288,7 @@ bool PartManager::eventFilter( TQObject *obj, TQEvent *ev )
return false;
}
- w = w->tqparentWidget();
+ w = w->parentWidget();
if ( w && ( ( w->testWFlags( WType_Dialog ) && w->isModal() ) ||
w->testWFlags( WType_Popup ) || w->testWFlags( WStyle_Tool ) ) )
@@ -307,19 +307,19 @@ bool PartManager::eventFilter( TQObject *obj, TQEvent *ev )
return false;
}
-Part * PartManager::tqfindPartFromWidget( TQWidget * widget, const TQPoint &pos )
+Part * PartManager::findPartFromWidget( TQWidget * widget, const TQPoint &pos )
{
TQPtrListIterator<Part> it ( d->m_parts );
for ( ; it.current() ; ++it )
{
Part *part = it.current()->hitTest( widget, pos );
- if ( part && d->m_parts.tqfindRef( part ) != -1 )
+ if ( part && d->m_parts.findRef( part ) != -1 )
return part;
}
return 0L;
}
-Part * PartManager::tqfindPartFromWidget( TQWidget * widget )
+Part * PartManager::findPartFromWidget( TQWidget * widget )
{
TQPtrListIterator<Part> it ( d->m_parts );
for ( ; it.current() ; ++it )
@@ -332,7 +332,7 @@ Part * PartManager::tqfindPartFromWidget( TQWidget * widget )
void PartManager::addPart( Part *part, bool setActive )
{
- if ( d->m_parts.tqfindRef( part ) != -1 ) // don't add parts more than once :)
+ if ( d->m_parts.findRef( part ) != -1 ) // don't add parts more than once :)
{
#ifdef DEBUG_PARTMANAGER
kdWarning(1000) << k_funcinfo << part << " already added" << kdBacktrace(5) << endl;
@@ -368,7 +368,7 @@ void PartManager::addPart( Part *part, bool setActive )
void PartManager::removePart( Part *part )
{
- if ( d->m_parts.tqfindRef( part ) == -1 )
+ if ( d->m_parts.findRef( part ) == -1 )
{
kdFatal(1000) << TQString("Can't remove part %1, not in KPartManager's list.").arg(part->name()) << endl;
return;
@@ -390,11 +390,11 @@ void PartManager::removePart( Part *part )
setSelectedPart( 0 );
}
-void PartManager::tqreplacePart( Part * oldPart, Part * newPart, bool setActive )
+void PartManager::replacePart( Part * oldPart, Part * newPart, bool setActive )
{
- //kdDebug(1000) << "tqreplacePart " << oldPart->name() << "-> " << newPart->name() << " setActive=" << setActive << endl;
+ //kdDebug(1000) << "replacePart " << oldPart->name() << "-> " << newPart->name() << " setActive=" << setActive << endl;
// This methods does exactly removePart + addPart but without calling setActivePart(0) in between
- if ( d->m_parts.tqfindRef( oldPart ) == -1 )
+ if ( d->m_parts.findRef( oldPart ) == -1 )
{
kdFatal(1000) << TQString("Can't remove part %1, not in KPartManager's list.").arg(oldPart->name()) << endl;
return;
@@ -410,7 +410,7 @@ void PartManager::tqreplacePart( Part * oldPart, Part * newPart, bool setActive
void PartManager::setActivePart( Part *part, TQWidget *widget )
{
- if ( part && d->m_parts.tqfindRef( part ) == -1 )
+ if ( part && d->m_parts.findRef( part ) == -1 )
{
kdWarning( 1000 ) << "PartManager::setActivePart : trying to activate a non-registered part! " << part->name() << endl;
return; // don't allow someone call setActivePart with a part we don't know about
@@ -565,7 +565,7 @@ void PartManager::addManagedTopLevelWidget( const TQWidget *topLevel )
if ( !topLevel->isTopLevel() )
return;
- if ( d->m_managedTopLevelWidgets.tqcontainsRef( topLevel ) )
+ if ( d->m_managedTopLevelWidgets.containsRef( topLevel ) )
return;
d->m_managedTopLevelWidgets.append( topLevel );
@@ -578,7 +578,7 @@ void PartManager::removeManagedTopLevelWidget( const TQWidget *topLevel )
if ( !topLevel->isTopLevel() )
return;
- if ( d->m_managedTopLevelWidgets.tqfindRef( topLevel ) == -1 )
+ if ( d->m_managedTopLevelWidgets.findRef( topLevel ) == -1 )
return;
d->m_managedTopLevelWidgets.remove();
diff --git a/kparts/partmanager.h b/kparts/partmanager.h
index cf2687456..a9b150a67 100644
--- a/kparts/partmanager.h
+++ b/kparts/partmanager.h
@@ -47,7 +47,7 @@ class PartManagerPrivate;
* Parts know about the part manager to add nested parts to it.
* See also KParts::Part::manager() and KParts::Part::setManager().
*/
-class KPARTS_EXPORT PartManager : public TQObject
+class KPARTS_EXPORT PartManager : public QObject
{
Q_OBJECT
Q_ENUMS( SelectionPolicy )
@@ -165,7 +165,7 @@ public:
* @p setActive is true.
* This is an optimised version of removePart + addPart
*/
- virtual void tqreplacePart( Part * oldPart, Part * newPart, bool setActive = true );
+ virtual void replacePart( Part * oldPart, Part * newPart, bool setActive = true );
/**
* Sets the active part.
@@ -274,8 +274,8 @@ protected slots:
*/
void slotManagedTopLevelWidgetDestroyed();
private:
- Part * tqfindPartFromWidget( TQWidget * widget, const TQPoint &pos );
- Part * tqfindPartFromWidget( TQWidget * widget );
+ Part * findPartFromWidget( TQWidget * widget, const TQPoint &pos );
+ Part * findPartFromWidget( TQWidget * widget );
protected:
virtual void virtual_hook( int id, void* data );
diff --git a/kparts/plugin.cpp b/kparts/plugin.cpp
index b9b60fc0b..c9b0d2e36 100644
--- a/kparts/plugin.cpp
+++ b/kparts/plugin.cpp
@@ -68,7 +68,7 @@ TQString Plugin::xmlFile() const
if ( !d->m_parentInstance || ( path.length() > 0 && path[ 0 ] == '/' ) )
return path;
- TQString absPath = locate( "data", TQString::tqfromLatin1( d->m_parentInstance->instanceName() ) + '/' + path );
+ TQString absPath = locate( "data", TQString::fromLatin1( d->m_parentInstance->instanceName() ) + '/' + path );
assert( !absPath.isEmpty() );
return absPath;
}
@@ -80,7 +80,7 @@ TQString Plugin::localXMLFile() const
if ( !d->m_parentInstance || ( path.length() > 0 && path[ 0 ] == '/' ) )
return path;
- TQString absPath = locateLocal( "data", TQString::tqfromLatin1( d->m_parentInstance->instanceName() ) + '/' + path );
+ TQString absPath = locateLocal( "data", TQString::fromLatin1( d->m_parentInstance->instanceName() ) + '/' + path );
assert( !absPath.isEmpty() );
return absPath;
}
@@ -104,10 +104,10 @@ TQValueList<Plugin::PluginInfo> Plugin::pluginInfos( const KInstance * instance
for (; pIt != pEnd; ++pIt )
{
TQFileInfo fInfo( *pIt );
- if ( fInfo.extension() == TQString::tqfromLatin1( "desktop" ) )
+ if ( fInfo.extension() == TQString::fromLatin1( "desktop" ) )
continue;
- TQMap<TQString,TQStringList>::Iterator mapIt = sortedPlugins.tqfind( fInfo.fileName() );
+ TQMap<TQString,TQStringList>::Iterator mapIt = sortedPlugins.find( fInfo.fileName() );
if ( mapIt == sortedPlugins.end() )
mapIt = sortedPlugins.insert( fInfo.fileName(), TQStringList() );
@@ -249,7 +249,7 @@ void Plugin::loadPlugins( TQObject *parent, KXMLGUIClient* parentGUIClient, KIns
else
{ // no user-setting, load plugin default setting
TQString relPath = TQString( instance->instanceName() ) + "/" + (*pIt).m_relXMLFileName;
- relPath.truncate( relPath.tqfindRev( '.' ) ); // remove extension
+ relPath.truncate( relPath.findRev( '.' ) ); // remove extension
relPath += ".desktop";
//kdDebug(1000) << "looking for " << relPath << endl;
const TQString desktopfile = instance->dirs()->findResource( "data", relPath );
diff --git a/kparts/plugin.h b/kparts/plugin.h
index 9c2c16512..829687c6e 100644
--- a/kparts/plugin.h
+++ b/kparts/plugin.h
@@ -111,7 +111,7 @@ public:
* Plugin objects children of @p parent, and insert the plugin as a child GUI client
* of @p parentGUIClient.
*
- * This method uses the KConfig object of the given instance, to tqfind out which
+ * This method uses the KConfig object of the given instance, to find out which
* plugins are enabled and which are disabled. What happens by default (i.e.
* for new plugins that are not in that config file) is controlled by
* @p enableNewPluginsByDefault. It can be overridden by the plugin if it
diff --git a/kparts/statusbarextension.cpp b/kparts/statusbarextension.cpp
index 7dcf3d800..6b0ee3cb2 100644
--- a/kparts/statusbarextension.cpp
+++ b/kparts/statusbarextension.cpp
@@ -135,7 +135,7 @@ KStatusBar * StatusBarExtension::statusBar() const
{
if ( !m_statusBar ) {
TQWidget* w = static_cast<KParts::ReadOnlyPart*>(parent())->widget();
- KMainWindow* mw = dynamic_cast<KMainWindow *>( w->tqtopLevelWidget() );
+ KMainWindow* mw = dynamic_cast<KMainWindow *>( w->topLevelWidget() );
if ( mw )
m_statusBar = mw->statusBar();
}
diff --git a/kparts/statusbarextension.h b/kparts/statusbarextension.h
index 81bf6854b..79d449a98 100644
--- a/kparts/statusbarextension.h
+++ b/kparts/statusbarextension.h
@@ -50,7 +50,7 @@ namespace KParts
*
* @since 3.2
*/
- class KPARTS_EXPORT StatusBarExtension : public TQObject
+ class KPARTS_EXPORT StatusBarExtension : public QObject
{
Q_OBJECT
diff --git a/kparts/tests/example.cpp b/kparts/tests/example.cpp
index 22c87f30c..a1e8110e5 100644
--- a/kparts/tests/example.cpp
+++ b/kparts/tests/example.cpp
@@ -79,7 +79,7 @@ void Shell::embedEditor()
if ( m_manager->activePart() == m_part2 )
createGUI( 0L );
- // tqreplace part2 with the editor part
+ // replace part2 with the editor part
delete m_part2;
m_part2 = 0L;
m_editorpart = new NotepadPart( m_splitter, "editor",
diff --git a/kparts/tests/ghostview.cpp b/kparts/tests/ghostview.cpp
index 2ba2bd1d2..a1ace7720 100644
--- a/kparts/tests/ghostview.cpp
+++ b/kparts/tests/ghostview.cpp
@@ -25,7 +25,7 @@ Shell::Shell()
KAction * paQuit = new KAction( "&Quit" , "exit", 0, this, TQT_SLOT( close() ), actionCollection(), "file_quit" );
- // Try to tqfind a postscript component first
+ // Try to find a postscript component first
KTrader::OfferList offers = KTrader::self()->query("application/postscript", "('KParts/ReadOnlyPart' in ServiceTypes) or ('Browser/View' in ServiceTypes)");
KLibFactory *factory = 0;
@@ -47,7 +47,7 @@ Shell::Shell()
}
}
- // if we couldn't tqfind a component with the trader, try the
+ // if we couldn't find a component with the trader, try the
// kghostview library directly. if this ever happens, then something
// is seriously screwed up, though -- the kghostview component
// should be picked up by the trader
diff --git a/kparts/tests/normalktm.cpp b/kparts/tests/normalktm.cpp
index e8fdae56d..ec4420a7e 100644
--- a/kparts/tests/normalktm.cpp
+++ b/kparts/tests/normalktm.cpp
@@ -74,7 +74,7 @@ void Shell::slotFileOpenRemote()
void Shell::embedEditor()
{
- // tqreplace part2 with the editor part
+ // replace part2 with the editor part
delete m_part2;
m_part2 = 0L;
m_editorpart = new NotepadPart( m_splitter, "editor",
diff --git a/kparts/tests/notepad.cpp b/kparts/tests/notepad.cpp
index 3a46f76c3..e0857a51e 100644
--- a/kparts/tests/notepad.cpp
+++ b/kparts/tests/notepad.cpp
@@ -16,17 +16,17 @@
#include <kstatusbar.h>
#include <kstandarddirs.h>
-NotepadPart::NotepadPart( TQWidget* tqparentWidget, const char*,
+NotepadPart::NotepadPart( TQWidget* parentWidget, const char*,
TQObject* parent, const char* name,
const TQStringList& )
: KParts::ReadWritePart( parent, name )
{
setInstance( NotepadFactory::instance() );
- m_edit = new TQMultiLineEdit( tqparentWidget, "NotepadPart's multiline edit" );
+ m_edit = new TQMultiLineEdit( parentWidget, "NotepadPart's multiline edit" );
setWidget( m_edit );
- (void)new KAction( "Search and tqreplace", 0, this, TQT_SLOT( slotSearchReplace() ), actionCollection(), "searchtqreplace" );
+ (void)new KAction( "Search and replace", 0, this, TQT_SLOT( slotSearchReplace() ), actionCollection(), "searchreplace" );
setXMLFile( "notepadpart.rc" );
setReadWrite( true );
}
diff --git a/kparts/tests/notepad.desktop b/kparts/tests/notepad.desktop
index 29fd1b17c..e7f1bb432 100644
--- a/kparts/tests/notepad.desktop
+++ b/kparts/tests/notepad.desktop
@@ -80,7 +80,7 @@ Name[zh_CN]=记事本(例子)
Name[zh_HK]=記事本(範例)
Name[zh_TW]=記事本(範例)
Name[zu]=Incwadi yokubhala (umfanekiso)
-MimeType=text/english;text/plain;text/x-makefile;text/x-c++hdr;text/x-c++src;text/x-chdr;text/x-csrc;text/x-java;text/x-tqmoc;text/x-pascal;text/x-tcl;text/x-tex;application/x-shellscript;text/x-c;text/x-c++;
+MimeType=text/english;text/plain;text/x-makefile;text/x-c++hdr;text/x-c++src;text/x-chdr;text/x-csrc;text/x-java;text/x-moc;text/x-pascal;text/x-tcl;text/x-tex;application/x-shellscript;text/x-c;text/x-c++;
ServiceTypes=KParts/ReadOnlyPart
X-KDE-Library=libnotepadpart
Type=Service
diff --git a/kparts/tests/notepadpart.rc b/kparts/tests/notepadpart.rc
index 272f6cbc9..ba30eb322 100644
--- a/kparts/tests/notepadpart.rc
+++ b/kparts/tests/notepadpart.rc
@@ -3,11 +3,11 @@
<MenuBar>
<Menu name="file"><Text>&amp;File</Text>
<Menu name="NotepadSubMenu"><text>Notepad Stuff</text>
- <Action name="searchtqreplace"/>
+ <Action name="searchreplace"/>
</Menu>
</Menu>
<Menu name="edit"><Text>&amp;Edit</Text>
- <Action name="searchtqreplace"/>
+ <Action name="searchreplace"/>
</Menu>
</MenuBar>
<StatusBar/>
diff --git a/kparts/tests/parts.cpp b/kparts/tests/parts.cpp
index f11f0194f..d932a168f 100644
--- a/kparts/tests/parts.cpp
+++ b/kparts/tests/parts.cpp
@@ -18,12 +18,12 @@
#include <kaction.h>
#include <klocale.h>
-Part1::Part1( TQObject *parent, TQWidget * tqparentWidget )
+Part1::Part1( TQObject *parent, TQWidget * parentWidget )
: KParts::ReadOnlyPart( parent, "Part1" )
{
m_instance = new KInstance( "kpartstestpart" );
setInstance( m_instance );
- m_edit = new TQMultiLineEdit( tqparentWidget );
+ m_edit = new TQMultiLineEdit( parentWidget );
setWidget( m_edit );
setXMLFile( "kpartstest_part1.rc" );
@@ -56,12 +56,12 @@ bool Part1::openFile()
return true;
}
-Part2::Part2( TQObject *parent, TQWidget * tqparentWidget )
+Part2::Part2( TQObject *parent, TQWidget * parentWidget )
: KParts::Part( parent, "Part2" )
{
m_instance = new KInstance( "part2" );
setInstance( m_instance );
- TQWidget * w = new TQWidget( tqparentWidget, "Part2Widget" );
+ TQWidget * w = new TQWidget( parentWidget, "Part2Widget" );
setWidget( w );
TQCheckBox * cb = new TQCheckBox( "something", w );
diff --git a/kparts/tests/parts.h b/kparts/tests/parts.h
index 873a6fea4..6f373a85c 100644
--- a/kparts/tests/parts.h
+++ b/kparts/tests/parts.h
@@ -13,7 +13,7 @@ class Part1 : public KParts::ReadOnlyPart
{
Q_OBJECT
public:
- Part1( TQObject *parent, TQWidget * tqparentWidget );
+ Part1( TQObject *parent, TQWidget * parentWidget );
virtual ~Part1();
protected:
@@ -28,7 +28,7 @@ class Part2 : public KParts::Part
{
Q_OBJECT
public:
- Part2( TQObject *parent, TQWidget * tqparentWidget );
+ Part2( TQObject *parent, TQWidget * parentWidget );
virtual ~Part2();
protected:
diff --git a/kparts/tests/plugin_foobar.rc b/kparts/tests/plugin_foobar.rc
index 377c6b901..e614e505f 100644
--- a/kparts/tests/plugin_foobar.rc
+++ b/kparts/tests/plugin_foobar.rc
@@ -2,10 +2,10 @@
<kpartplugin library="libfoobar">
<MenuBar>
<Menu name="file"><Text>&amp;File</Text>
- <Action name="searchtqreplace"/>
+ <Action name="searchreplace"/>
</Menu>
<Menu name="woohoo"><Text>fun</Text>
- <Action name="searchtqreplace"/>
+ <Action name="searchreplace"/>
</Menu>
</MenuBar>
<ToolBar name="gah"/>
diff --git a/kparts/tests/plugin_spellcheck.rc b/kparts/tests/plugin_spellcheck.rc
index 495148d91..1980186cf 100644
--- a/kparts/tests/plugin_spellcheck.rc
+++ b/kparts/tests/plugin_spellcheck.rc
@@ -6,9 +6,9 @@
</Menu>
<Menu name="SomePluginMenu"><text>Some Cool Plugin Menu</text>
<Action name="spellcheck"/>
- <Action name="searchtqreplace"/>
+ <Action name="searchreplace"/>
<Menu name="WhatASubMenu"><text>Yep</text>
- <Action name="searchtqreplace"/>
+ <Action name="searchreplace"/>
</Menu>
</Menu>
</MenuBar>
diff --git a/kparts/browserextension.h b/kparts/browserextension.h
index 889f8d2fb..edb376d27 100644
--- a/kparts/browserextension.h
+++ b/kparts/browserextension.h
@@ -187,7 +187,7 @@ struct KPARTS_EXPORT WindowArgs
~WindowArgs();
WindowArgs( const WindowArgs &args );
WindowArgs &operator=( const WindowArgs &args );
- WindowArgs( const TQRect &_tqgeometry, bool _fullscreen, bool _menuBarVisible,
+ WindowArgs( const TQRect &_geometry, bool _fullscreen, bool _menuBarVisible,
bool _toolBarsVisible, bool _statusBarVisible, bool _resizable );
WindowArgs( int _x, int _y, int _width, int _height, bool _fullscreen,
bool _menuBarVisible, bool _toolBarsVisible,
@@ -257,7 +257,7 @@ class BrowserExtensionPrivate;
* to implement the virtual methods [and the standard-actions slots, see below].
*
* The way to associate the BrowserExtension with the part is to simply
* create the BrowserExtension as a child of the part (in TQObject's terms).
* The hosting application will look for it automatically.
*
* Another aspect of the browser integration is that a set of standard
@@ -305,7 +305,7 @@ class BrowserExtensionPrivate;
* otherwise, they are saved globally.
* @li @p disableScrolling: no scrollbars
*/
-class KPARTS_EXPORT BrowserExtension : public TQObject
+class KPARTS_EXPORT BrowserExtension : public QObject
{
Q_OBJECT
Q_PROPERTY( bool urlDropHandling READ isURLDropHandlingEnabled WRITE setURLDropHandlingEnabled )
@@ -333,7 +333,7 @@ public:
* ShowBookmark: show "add to bookmarks" (usually not done on the local filesystem)
* ShowCreateDirectory: show "create directory" (usually only done on the background of the view, or
* in hierarchical views like directory trees, where the new dir would be visible)
- * ShowTextSelectionItems: set when selecting text, for a popup that only tqcontains text-related items.
+ * ShowTextSelectionItems: set when selecting text, for a popup that only contains text-related items.
* NoDeletion: deletion, trashing and renaming not allowed (e.g. parent dir not writeable).
* (this is only needed if the protocol itself supports deletion, unlike e.g. HTTP)
*
@@ -446,7 +446,7 @@ public:
* Checking if the extension implements a certain slot can be done like this:
*
* \code
- * extension->tqmetaObject()->slotNames().tqcontains( actionName + "()" )
+ * extension->metaObject()->slotNames().contains( actionName + "()" )
* \endcode
*
* (note that @p actionName is the iterator's key value if already
@@ -721,7 +721,7 @@ private:
* other parts.
* For instance a KHTMLPart hosts one part per frame.
*/
-class KPARTS_EXPORT BrowserHostExtension : public TQObject
+class KPARTS_EXPORT BrowserHostExtension : public QObject
{
Q_OBJECT
public:
@@ -745,11 +745,11 @@ public:
virtual const TQPtrList<KParts::ReadOnlyPart> frames() const;
/**
- * Returns the part that tqcontains @p frame and that may be accessed
+ * Returns the part that contains @p frame and that may be accessed
* by @p callingPart
* @since 3.3
*/
- BrowserHostExtension *tqfindFrameParent(KParts::ReadOnlyPart *callingPart, const TQString &frame);
+ BrowserHostExtension *findFrameParent(KParts::ReadOnlyPart *callingPart, const TQString &frame);
/**
* Opens the given url in a hosted child frame. The frame name is specified in the
@@ -789,7 +789,7 @@ private:
* A part can have an object hierarchie by using objid as a reference
* to an object.
*/
-class KPARTS_EXPORT LiveConnectExtension : public TQObject
+class KPARTS_EXPORT LiveConnectExtension : public QObject
{
Q_OBJECT
public:
@@ -257,7 +257,7 @@ class BrowserExtensionPrivate;
*
* The way to associate the BrowserExtension with the part is to simply
- * create the BrowserExtension as a child of the part (in TQObject's terms).
+ * create the BrowserExtension as a child of the part (in QObject's terms).
* The hosting application will look for it automatically.
*
diff --git a/kparts/browserrun.cpp b/kparts/browserrun.cpp
index e77f1f87e..4d23d6300 100644
--- a/kparts/browserrun.cpp
+++ b/kparts/browserrun.cpp
@@ -71,7 +71,7 @@ void BrowserRun::init()
{
if ( d->m_bHideErrorDialog )
{
- // ### KRun doesn't call a virtual method when it tqfinds out that the URL
+ // ### KRun doesn't call a virtual method when it finds out that the URL
// is either malformed, or points to a non-existing local file...
// So we need to reimplement some of the checks, to handle m_bHideErrorDialog
if ( !m_strURL.isValid() ) {
@@ -128,7 +128,7 @@ void BrowserRun::scanFile()
}
// Set the PropagateHttpHeader meta-data if it has not already been set...
- if (!m_args.metaData().tqcontains("PropagateHttpHeader"))
+ if (!m_args.metaData().contains("PropagateHttpHeader"))
m_args.metaData().insert("PropagateHttpHeader", "TRUE");
}
@@ -209,7 +209,7 @@ BrowserRun::NonEmbeddableResult BrowserRun::handleNonEmbeddable( const TQString&
!m_strURL.isLocalFile() )
{
if ( isTextExecutable(mimeType) )
- mimeType = TQString::tqfromLatin1("text/plain"); // view, don't execute
+ mimeType = TQString::fromLatin1("text/plain"); // view, don't execute
kdDebug(1000) << "BrowserRun: ask for saving" << endl;
KService::Ptr offer = KServiceTypeProfile::preferredService(mimeType, "Application");
// ... -> ask whether to save
@@ -236,7 +236,7 @@ BrowserRun::NonEmbeddableResult BrowserRun::handleNonEmbeddable( const TQString&
m_sMimeType = mimeType;
TQString extension;
TQString fileName = m_suggestedFilename.isEmpty() ? m_strURL.fileName() : m_suggestedFilename;
- int extensionPos = fileName.tqfindRev( '.' );
+ int extensionPos = fileName.findRev( '.' );
if ( extensionPos != -1 )
extension = fileName.mid( extensionPos ); // keep the '.'
KTempFile tempFile( TQString::null, extension );
@@ -313,7 +313,7 @@ BrowserRun::AskSaveResult BrowserRun::askSave( const KURL & url, KService::Ptr o
int choice = KMessageBox::questionYesNoCancel(
0L, question, url.host(),
KStdGuiItem::saveAs(), openText,
- TQString::tqfromLatin1("askSave")+ mimeType ); // dontAskAgainName, KEEP IN SYNC!!!
+ TQString::fromLatin1("askSave")+ mimeType ); // dontAskAgainName, KEEP IN SYNC!!!
return choice == KMessageBox::Yes ? Save : ( choice == KMessageBox::No ? Open : Cancel );
// SYNC SYNC SYNC SYNC SYNC SYNC SYNC SYNC SYNC SYNC SYNC SYNC SYNC SYNC
@@ -341,8 +341,8 @@ BrowserRun::AskSaveResult BrowserRun::askEmbedOrSave( const KURL & url, const TQ
mime->is( "text/xml" ) ||
mime->is( "inode/directory" ) ||
mimeType.startsWith( "image" ) ||
- mime->is( "multipart/x-mixed-tqreplace" ) ||
- mime->is( "multipart/tqreplace" ) ||
+ mime->is( "multipart/x-mixed-replace" ) ||
+ mime->is( "multipart/replace" ) ||
mimeType.startsWith( "print" ) ) )
return Open;
@@ -351,7 +351,7 @@ BrowserRun::AskSaveResult BrowserRun::askEmbedOrSave( const KURL & url, const TQ
int choice = KMessageBox::questionYesNoCancel(
0L, question, url.host(),
KStdGuiItem::saveAs(), KGuiItem( i18n( "&Open" ), "fileopen"),
- TQString::tqfromLatin1("askEmbedOrSave")+ mimeType ); // dontAskAgainName, KEEP IN SYNC!!!
+ TQString::fromLatin1("askEmbedOrSave")+ mimeType ); // dontAskAgainName, KEEP IN SYNC!!!
return choice == KMessageBox::Yes ? Save : ( choice == KMessageBox::No ? Open : Cancel );
// SYNC SYNC SYNC SYNC SYNC SYNC SYNC SYNC SYNC SYNC SYNC SYNC SYNC SYNC
}
@@ -372,7 +372,7 @@ void BrowserRun::simpleSave( const KURL & url, const TQString & suggestedFilenam
TQWidget* window )
{
// DownloadManager <-> konqueror integration
// tqfind if the integration is enabled
// the empty key means no integration
// only use the downloadmanager for non-local urls
if ( !url.isLocalFile() )
@@ -382,7 +382,7 @@ void BrowserRun::simpleSave( const KURL & url, const TQString & suggestedFilenam
TQString downloadManger = cfg.readPathEntry("DownloadManager");
if (!downloadManger.isEmpty())
{
// then tqfind the download manager location
kdDebug(1000) << "Using: "<<downloadManger <<" as Download Manager" <<endl;
TQString cmd=KStandardDirs::findExe(downloadManger);
if (cmd.isEmpty())
@@ -372,7 +372,7 @@ void BrowserRun::simpleSave( const KURL & url, const TQString & suggestedFilenam
{
// DownloadManager <-> konqueror integration
- // tqfind if the integration is enabled
+ // find if the integration is enabled
// the empty key means no integration
// only use the downloadmanager for non-local urls
@@ -382,7 +382,7 @@ void BrowserRun::simpleSave( const KURL & url, const TQString & suggestedFilenam
if (!downloadManger.isEmpty())
{
- // then tqfind the download manager location
+ // then find the download manager location
kdDebug(1000) << "Using: "<<downloadManger <<" as Download Manager" <<endl;
TQString cmd=KStandardDirs::findExe(downloadManger);
diff --git a/kparts/componentfactory.h b/kparts/componentfactory.h
index dc85663b0..7e9de4280 100644
--- a/kparts/componentfactory.h
+++ b/kparts/componentfactory.h
@@ -82,7 +82,7 @@ namespace KParts
* \endcode
*
* @param factory The factory to ask for the creation of the component
* @param tqparentWidget the parent widget for the part
* @param widgetName the name of the part's widget
* @param parent The parent object (see TQObject constructor)
* @param name The name of the object to create (see TQObject constructor)
@@ -93,13 +93,13 @@ namespace KParts
*/
template <class T>
static T *createPartInstanceFromFactory( KParts::Factory *factory,
- TQWidget *tqparentWidget = 0,
+ TQWidget *parentWidget = 0,
const char *widgetName = 0,
TQObject *parent = 0,
const char *name = 0,
const TQStringList &args = TQStringList() )
{
- KParts::Part *object = factory->createPart( tqparentWidget, widgetName,
+ KParts::Part *object = factory->createPart( parentWidget, widgetName,
parent, name,
T::staticMetaObject()->className(),
args );
@@ -156,7 +156,7 @@ namespace KParts
template <class T>
static T *createPartInstanceFromLibrary( const char *libraryName,
- TQWidget *tqparentWidget = 0,
+ TQWidget *parentWidget = 0,
const char *widgetName = 0,
TQObject *parent = 0,
const char *name = 0,
@@ -186,7 +186,7 @@ namespace KParts
*error = ErrNoFactory;
return 0;
}
- T *res = createPartInstanceFromFactory<T>( partFactory, tqparentWidget,
+ T *res = createPartInstanceFromFactory<T>( partFactory, parentWidget,
widgetName, parent, name, args );
if ( !res )
{
@@ -218,7 +218,7 @@ namespace KParts
template <class T>
static T *createPartInstanceFromService( const KService::Ptr &service,
- TQWidget *tqparentWidget = 0,
+ TQWidget *parentWidget = 0,
const char *widgetName = 0,
TQObject *parent = 0,
const char *name = 0,
@@ -233,7 +233,7 @@ namespace KParts
return 0;
}
- return createPartInstanceFromLibrary<T>( library.local8Bit().data(), tqparentWidget,
+ return createPartInstanceFromLibrary<T>( library.local8Bit().data(), parentWidget,
widgetName, parent, name, args, error );
}
@@ -267,7 +267,7 @@ namespace KParts
template <class T, class ServiceIterator>
static T *createPartInstanceFromServices( ServiceIterator begin,
ServiceIterator end,
- TQWidget *tqparentWidget = 0,
+ TQWidget *parentWidget = 0,
const char *widgetName = 0,
TQObject *parent = 0,
const char *name = 0,
@@ -281,7 +281,7 @@ namespace KParts
if ( error )
*error = 0;
- T *component = createPartInstanceFromService<T>( service, tqparentWidget,
+ T *component = createPartInstanceFromService<T>( service, parentWidget,
widgetName, parent,
name, args, error );
if ( component )
@@ -306,7 +306,7 @@ namespace KParts
* }
* \endcode
*
- * @param serviceType the type of service for which to tqfind a plugin
+ * @param serviceType the type of service for which to find a plugin
* @param constraint an optional constraint to pass to the trader (see KIO::KTrader)
* @param parent the parent object for the part itself
* @param name the name that will be given to the part
@@ -344,18 +344,18 @@ namespace KParts
* You can use this method to create a generic viewer - that can display any
* kind of file, provided that there is a ReadOnlyPart installed for it - in 5 lines:
* \code
* // Given the following: KURL url, TQWidget* tqparentWidget and TQObject* parentObject.
* TQString mimetype = KMimeType::findByURL( url )->name();
- * KParts::ReadOnlyPart* part = KParts::ComponentFactory::createPartInstanceFromQuery<KParts::ReadOnlyPart>( mimetype, TQString::null, tqparentWidget, 0, parentObject, 0 );
+ * KParts::ReadOnlyPart* part = KParts::ComponentFactory::createPartInstanceFromQuery<KParts::ReadOnlyPart>( mimetype, TQString::null, parentWidget, 0, parentObject, 0 );
* if ( part ) {
* part->openURL( url );
* part->widget()->show(); // also insert the widget into a tqlayout, or simply use a TQVBox as tqparentWidget
* }
* \endcode
*
- * @param serviceType the type of service for which to tqfind a part, e.g. a mimetype
+ * @param serviceType the type of service for which to find a part, e.g. a mimetype
* @param constraint an optional constraint to pass to the trader (see KTrader)
* @param tqparentWidget the parent widget, will be set as the parent of the part's widget
* @param widgetName the name that will be given to the part's widget
* @param parent the parent object for the part itself
* @param name the name that will be given to the part
@@ -369,14 +369,14 @@ namespace KParts
template <class T>
static T *createPartInstanceFromQuery( const TQString &serviceType,
const TQString &constraint,
- TQWidget *tqparentWidget = 0,
+ TQWidget *parentWidget = 0,
const char *widgetName = 0,
TQObject *parent = 0,
const char *name = 0,
const TQStringList &args = TQStringList(),
int *error = 0 )
{
- KTrader::OfferList offers = KTrader::self()->query( serviceType, TQString::tqfromLatin1("KParts/ReadOnlyPart"), constraint, TQString::null );
+ KTrader::OfferList offers = KTrader::self()->query( serviceType, TQString::fromLatin1("KParts/ReadOnlyPart"), constraint, TQString::null );
if ( offers.isEmpty() )
{
if ( error )
@@ -385,7 +385,7 @@ namespace KParts
}
return createPartInstanceFromServices<T>( offers.begin(), offers.end(),
- tqparentWidget, widgetName,
+ parentWidget, widgetName,
parent, name, args, error );
}
@@ -82,7 +82,7 @@ namespace KParts
*
* @param factory The factory to ask for the creation of the component
- * @param tqparentWidget the parent widget for the part
+ * @param parentWidget the parent widget for the part
* @param widgetName the name of the part's widget
* @param parent The parent object (see TQObject constructor)
@@ -344,18 +344,18 @@ namespace KParts
* kind of file, provided that there is a ReadOnlyPart installed for it - in 5 lines:
* \code
- * // Given the following: KURL url, TQWidget* tqparentWidget and TQObject* parentObject.
+ * // Given the following: KURL url, TQWidget* parentWidget and TQObject* parentObject.
* TQString mimetype = KMimeType::findByURL( url )->name();
@@ -344,18 +344,18 @@ namespace KParts
* if ( part ) {
* part->openURL( url );
- * part->widget()->show(); // also insert the widget into a tqlayout, or simply use a TQVBox as tqparentWidget
+ * part->widget()->show(); // also insert the widget into a layout, or simply use a TQVBox as parentWidget
* }
* \endcode
@@ -344,18 +344,18 @@ namespace KParts
* @param constraint an optional constraint to pass to the trader (see KTrader)
- * @param tqparentWidget the parent widget, will be set as the parent of the part's widget
+ * @param parentWidget the parent widget, will be set as the parent of the part's widget
* @param widgetName the name that will be given to the part's widget
* @param parent the parent object for the part itself
diff --git a/kparts/factory.h b/kparts/factory.h
index 2ac834ba4..c1b98eca1 100644
--- a/kparts/factory.h
+++ b/kparts/factory.h
@@ -60,7 +60,7 @@ public:
* \endcode
* This could result in a call to
* \code
* createPart( tqparentWidget, name, parentObject, parentName, "KParts::Part",
* TQStringList("name1="value1"", "name2="value2") );
* \endcode
*
@@ -71,7 +71,7 @@ public:
* important for reference counting, and allows unloading the
* library automatically once all its objects have been destroyed.
*/
- Part *createPart( TQWidget *tqparentWidget = 0, const char *widgetName = 0, TQObject *parent = 0, const char *name = 0, const char *classname = "KParts::Part", const TQStringList &args = TQStringList() );
+ Part *createPart( TQWidget *parentWidget = 0, const char *widgetName = 0, TQObject *parent = 0, const char *name = 0, const char *classname = "KParts::Part", const TQStringList &args = TQStringList() );
/**
* If you have a part contained in a shared library you might want to query
@@ -108,13 +108,13 @@ protected:
* \endcode
* This could result in a call to
* \code
* createPart( tqparentWidget, name, parentObject, parentName, "Kparts::Part",
* TQStringList("name1="value1"", "name2="value2") );
* \endcode
*
* @returns the newly created part.
*/
- virtual Part *createPartObject( TQWidget *tqparentWidget = 0, const char *widgetName = 0, TQObject *parent = 0, const char *name = 0, const char *classname = "KParts::Part", const TQStringList &args = TQStringList() ) = 0;
+ virtual Part *createPartObject( TQWidget *parentWidget = 0, const char *widgetName = 0, TQObject *parent = 0, const char *name = 0, const char *classname = "KParts::Part", const TQStringList &args = TQStringList() ) = 0;
/**
* Reimplemented from KLibFactory. Calls createPart()
@@ -60,7 +60,7 @@ public:
* This could result in a call to
* \code
- * createPart( tqparentWidget, name, parentObject, parentName, "KParts::Part",
+ * createPart( parentWidget, name, parentObject, parentName, "KParts::Part",
* TQStringList("name1="value1"", "name2="value2") );
* \endcode
@@ -108,13 +108,13 @@ protected:
* This could result in a call to
* \code
- * createPart( tqparentWidget, name, parentObject, parentName, "Kparts::Part",
+ * createPart( parentWidget, name, parentObject, parentName, "Kparts::Part",
* TQStringList("name1="value1"", "name2="value2") );
* \endcode